@@ -21,7 +21,7 @@ sub ProcessKodakPatch($$$);
 sub WriteUnknownOrPreview($$$);
 sub FixLeicaBase($$;$);
 
-$VERSION = '1.98';
+$VERSION = '1.99';
 
 my $debug;          # set to 1 to enable debugging code
 
@@ -89,6 +89,15 @@ my $debug;          # set to 1 to enable debugging code
             FixBase => 1, # necessary for AVI and MOV videos
         },
     },
+    {
+        Name => 'MakerNoteDJI',
+        Condition => '$$self{Make} eq "DJI" and $$valPt !~ /^...\@AMBA/s',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::DJI::Main',
+            Start => '$valuePtr',
+            ByteOrder => 'Unknown',
+        },
+    },
     {
         Name => 'MakerNoteFLIR',
         # (starts with IFD, Make is 'FLIR Systems AB' or 'FLIR Systems')
@@ -1723,7 +1732,7 @@ maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2017, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
